
<a href="https://codecov.io/gh/isys35/pyteledantic">
  <img src="https://codecov.io/gh/isys35/pyteledantic/branch/master/graph/badge.svg?token=OJ3FYTM2TE"/>
</a>
<a href="https://github.com/isys35/pyteledantic">
  <img src="https://img.shields.io/pypi/dm/pyteledantic"/>
</a>
<a href="https://github.com/isys35/pyteledantic">
  <img src="https://img.shields.io/pypi/v/pyteledantic"/>
</a>
<a href="https://github.com/isys35/pyteledantic">
  <img src="https://img.shields.io/github/last-commit/isys35/pyteledantic"/>
</a>
<h1>Pydantic models for Telegram Bot API</h1>
